==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/DomainDnsRecord.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "isOptional", 
    "label", 
    "recordType", 
    "supportedService", 
    "ttl"})
@JsonInclude(Include.NON_NULL)
public class DomainDnsRecord extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.domainDnsRecord";
    }

    @JsonProperty("isOptional")
    protected Boolean isOptional;

    @JsonProperty("label")
    protected String label;

    @JsonProperty("recordType")
    protected String recordType;

    @JsonProperty("supportedService")
    protected String supportedService;

    @JsonProperty("ttl")
    protected Integer ttl;

    protected DomainDnsRecord() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderDomainDnsRecord() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private Boolean isOptional;
        private String label;
        private String recordType;
        private String supportedService;
        private Integer ttl;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder isOptional(Boolean isOptional) {
            this.isOptional = isOptional;
            this.changedFields = changedFields.add("isOptional");
            return this;
        }

        public Builder label(String label) {
            this.label = label;
            this.changedFields = changedFields.add("label");
            return this;
        }

        public Builder recordType(String recordType) {
            this.recordType = recordType;
            this.changedFields = changedFields.add("recordType");
            return this;
        }

        public Builder supportedService(String supportedService) {
            this.supportedService = supportedService;
            this.changedFields = changedFields.add("supportedService");
            return this;
        }

        public Builder ttl(Integer ttl) {
            this.ttl = ttl;
            this.changedFields = changedFields.add("ttl");
            return this;
        }

        public DomainDnsRecord build() {
            DomainDnsRecord _x = new DomainDnsRecord();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.domainDnsRecord";
            _x.id = id;
            _x.isOptional = isOptional;
            _x.label = label;
            _x.recordType = recordType;
            _x.supportedService = supportedService;
            _x.ttl = ttl;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="isOptional")
    @JsonIgnore
    public Optional<Boolean> getIsOptional() {
        return Optional.ofNullable(isOptional);
    }

    public DomainDnsRecord withIsOptional(Boolean isOptional) {
        DomainDnsRecord _x = _copy();
        _x.changedFields = changedFields.add("isOptional");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainDnsRecord");
        _x.isOptional = isOptional;
        return _x;
    }

    @Property(name="label")
    @JsonIgnore
    public Optional<String> getLabel() {
        return Optional.ofNullable(label);
    }

    public DomainDnsRecord withLabel(String label) {
        DomainDnsRecord _x = _copy();
        _x.changedFields = changedFields.add("label");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainDnsRecord");
        _x.label = label;
        return _x;
    }

    @Property(name="recordType")
    @JsonIgnore
    public Optional<String> getRecordType() {
        return Optional.ofNullable(recordType);
    }

    public DomainDnsRecord withRecordType(String recordType) {
        DomainDnsRecord _x = _copy();
        _x.changedFields = changedFields.add("recordType");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainDnsRecord");
        _x.recordType = recordType;
        return _x;
    }

    @Property(name="supportedService")
    @JsonIgnore
    public Optional<String> getSupportedService() {
        return Optional.ofNullable(supportedService);
    }

    public DomainDnsRecord withSupportedService(String supportedService) {
        DomainDnsRecord _x = _copy();
        _x.changedFields = changedFields.add("supportedService");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainDnsRecord");
        _x.supportedService = supportedService;
        return _x;
    }

    @Property(name="ttl")
    @JsonIgnore
    public Optional<Integer> getTtl() {
        return Optional.ofNullable(ttl);
    }

    public DomainDnsRecord withTtl(Integer ttl) {
        DomainDnsRecord _x = _copy();
        _x.changedFields = changedFields.add("ttl");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainDnsRecord");
        _x.ttl = ttl;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public DomainDnsRecord patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        DomainDnsRecord _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public DomainDnsRecord put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        DomainDnsRecord _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private DomainDnsRecord _copy() {
        DomainDnsRecord _x = new DomainDnsRecord();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.isOptional = isOptional;
        _x.label = label;
        _x.recordType = recordType;
        _x.supportedService = supportedService;
        _x.ttl = ttl;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("DomainDnsRecord[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("isOptional=");
        b.append(this.isOptional);
        b.append(", ");
        b.append("label=");
        b.append(this.label);
        b.append(", ");
        b.append("recordType=");
        b.append(this.recordType);
        b.append(", ");
        b.append("supportedService=");
        b.append(this.supportedService);
        b.append(", ");
        b.append("ttl=");
        b.append(this.ttl);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/DomainDnsRecord.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "isOptional", 
    "label", 
    "recordType", 
    "supportedService", 
    "ttl"})
@JsonInclude(Include.NON_NULL)
public class DomainDnsRecord extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.domainDnsRecord";
    }

    @JsonProperty("isOptional")
    protected Boolean isOptional;

    @JsonProperty("label")
    protected String label;

    @JsonProperty("recordType")
    protected String recordType;

    @JsonProperty("supportedService")
    protected String supportedService;

    @JsonProperty("ttl")
    protected Integer ttl;

    protected DomainDnsRecord() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderDomainDnsRecord() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private Boolean isOptional;
        private String label;
        private String recordType;
        private String supportedService;
        private Integer ttl;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder isOptional(Boolean isOptional) {
            this.isOptional = isOptional;
            this.changedFields = changedFields.add("isOptional");
            return this;
        }

        public Builder label(String label) {
            this.label = label;
            this.changedFields = changedFields.add("label");
            return this;
        }

        public Builder recordType(String recordType) {
            this.recordType = recordType;
            this.changedFields = changedFields.add("recordType");
            return this;
        }

        public Builder supportedService(String supportedService) {
            this.supportedService = supportedService;
            this.changedFields = changedFields.add("supportedService");
            return this;
        }

        public Builder ttl(Integer ttl) {
            this.ttl = ttl;
            this.changedFields = changedFields.add("ttl");
            return this;
        }

        public DomainDnsRecord build() {
            DomainDnsRecord _x = new DomainDnsRecord();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.domainDnsRecord";
            _x.id = id;
            _x.isOptional = isOptional;
            _x.label = label;
            _x.recordType = recordType;
            _x.supportedService = supportedService;
            _x.ttl = ttl;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="isOptional")
    @JsonIgnore
    public Optional<Boolean> getIsOptional() {
        return Optional.ofNullable(isOptional);
    }

    public DomainDnsRecord withIsOptional(Boolean isOptional) {
        DomainDnsRecord _x = _copy();
        _x.changedFields = changedFields.add("isOptional");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainDnsRecord");
        _x.isOptional = isOptional;
        return _x;
    }

    @Property(name="label")
    @JsonIgnore
    public Optional<String> getLabel() {
        return Optional.ofNullable(label);
    }

    public DomainDnsRecord withLabel(String label) {
        DomainDnsRecord _x = _copy();
        _x.changedFields = changedFields.add("label");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainDnsRecord");
        _x.label = label;
        return _x;
    }

    @Property(name="recordType")
    @JsonIgnore
    public Optional<String> getRecordType() {
        return Optional.ofNullable(recordType);
    }

    public DomainDnsRecord withRecordType(String recordType) {
        DomainDnsRecord _x = _copy();
        _x.changedFields = changedFields.add("recordType");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainDnsRecord");
        _x.recordType = recordType;
        return _x;
    }

    @Property(name="supportedService")
    @JsonIgnore
    public Optional<String> getSupportedService() {
        return Optional.ofNullable(supportedService);
    }

    public DomainDnsRecord withSupportedService(String supportedService) {
        DomainDnsRecord _x = _copy();
        _x.changedFields = changedFields.add("supportedService");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainDnsRecord");
        _x.supportedService = supportedService;
        return _x;
    }

    @Property(name="ttl")
    @JsonIgnore
    public Optional<Integer> getTtl() {
        return Optional.ofNullable(ttl);
    }

    public DomainDnsRecord withTtl(Integer ttl) {
        DomainDnsRecord _x = _copy();
        _x.changedFields = changedFields.add("ttl");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.domainDnsRecord");
        _x.ttl = ttl;
        return _x;
    }

    public DomainDnsRecord withUnmappedField(String name, Object value) {
        DomainDnsRecord _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public DomainDnsRecord patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        DomainDnsRecord _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public DomainDnsRecord put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        DomainDnsRecord _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private DomainDnsRecord _copy() {
        DomainDnsRecord _x = new DomainDnsRecord();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.isOptional = isOptional;
        _x.label = label;
        _x.recordType = recordType;
        _x.supportedService = supportedService;
        _x.ttl = ttl;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("DomainDnsRecord[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("isOptional=");
        b.append(this.isOptional);
        b.append(", ");
        b.append("label=");
        b.append(this.label);
        b.append(", ");
        b.append("recordType=");
        b.append(this.recordType);
        b.append(", ");
        b.append("supportedService=");
        b.append(this.supportedService);
        b.append(", ");
        b.append("ttl=");
        b.append(this.ttl);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
